s/BuiltinLocation/ArtificialLocation/

git-svn-id: https://llvm.org/svn/llvm-project/cfe/trunk@186557 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/CodeGen/CGBlocks.cpp b/lib/CodeGen/CGBlocks.cpp
index bd97b25..ec4af58 100644
--- a/lib/CodeGen/CGBlocks.cpp
+++ b/lib/CodeGen/CGBlocks.cpp
@@ -1315,7 +1315,7 @@
                                           false);
   StartFunction(FD, C.VoidTy, Fn, FI, args, SourceLocation());
   // Don't emit any line table entries for the body of this function.
-  BuiltinLocation BL(*this, Builder);
+  ArtificialLocation AL(*this, Builder);
 
   llvm::Type *structPtrTy = blockInfo.StructureType->getPointerTo();
 
@@ -1490,7 +1490,7 @@
                                           false, false);
   StartFunction(FD, C.VoidTy, Fn, FI, args, SourceLocation());
   // Don't emit any line table entries for the body of this function.
-  BuiltinLocation BL(*this, Builder);
+  ArtificialLocation AL(*this, Builder);
 
   llvm::Type *structPtrTy = blockInfo.StructureType->getPointerTo();
 
diff --git a/lib/CodeGen/CGDebugInfo.cpp b/lib/CodeGen/CGDebugInfo.cpp
index 5e5caf3..b6cf2f9 100644
--- a/lib/CodeGen/CGDebugInfo.cpp
+++ b/lib/CodeGen/CGDebugInfo.cpp
@@ -68,7 +68,7 @@
   }
 }
 
-BuiltinLocation::BuiltinLocation(CodeGenFunction &CGF, CGBuilderTy &B)
+ArtificialLocation::ArtificialLocation(CodeGenFunction &CGF, CGBuilderTy &B)
   : DI(CGF.getDebugInfo()), Builder(B) {
   if (DI) {
     SavedLoc = DI->getLocation();
@@ -83,7 +83,7 @@
   }
 }
 
-BuiltinLocation::~BuiltinLocation() {
+ArtificialLocation::~ArtificialLocation() {
   if (DI) {
     assert(Builder.getCurrentDebugLocation().getLine() == 0);
     DI->CurLoc = SavedLoc;
diff --git a/lib/CodeGen/CGDebugInfo.h b/lib/CodeGen/CGDebugInfo.h
index 3b88b11..6eeb911 100644
--- a/lib/CodeGen/CGDebugInfo.h
+++ b/lib/CodeGen/CGDebugInfo.h
@@ -48,7 +48,7 @@
 /// the backend.
 class CGDebugInfo {
   friend class NoLocation;
-  friend class BuiltinLocation;
+  friend class ArtificialLocation;
   CodeGenModule &CGM;
   const CodeGenOptions::DebugInfoKind DebugKind;
   llvm::DIBuilder DBuilder;
@@ -403,8 +403,8 @@
   ~NoLocation();
 };
 
 /// BuiltinLocation - An RAII object that temporarily switches to an
 /// artificial debug location that has a valid scope, but no line
 /// information. This is useful when emitting compiler-generated
 /// helper functions that have no source location associated with
 /// them.
@@ -412,14 +412,14 @@
 /// This is necessary because pasing an empty SourceLocation to
 /// CGDebugInfo::setLocation() will result in the last valid location
 /// being reused.
-class BuiltinLocation {
+class ArtificialLocation {
   SourceLocation SavedLoc;
   CGDebugInfo *DI;
   CGBuilderTy &Builder;
 public:
-  BuiltinLocation(CodeGenFunction &CGF, CGBuilderTy &B);
+  ArtificialLocation(CodeGenFunction &CGF, CGBuilderTy &B);
   /// ~BuildinLocation - Autorestore everything back to normal.
-  ~BuiltinLocation();
+  ~ArtificialLocation();
 };
@@ -403,8 +403,8 @@
 };
 
-/// BuiltinLocation - An RAII object that temporarily switches to an
-/// artificial debug location that has a valid scope, but no line
+/// ArtificialLocation - An RAII object that temporarily switches to
+/// an artificial debug location that has a valid scope, but no line
 /// information. This is useful when emitting compiler-generated
 /// helper functions that have no source location associated with